/* SoccerBot - Giotto Controller Classes - BufferedImage_port
Copyright (C) 2006 Peter Wild, Krystian Szczurek, Georg Klima

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Contact:
Peter Wild, pwild - at - cosy.sbg.ac.at
Krystian Szczurek, szczurek - at - cosy.sbg.ac.at
Georg Klima, gklima - at - cosy.sbg.ac.at
University of Salzburg, Austria
*/
package at.ac.sbg.cosy.soccerbot.controller;

import giotto.functionality.interfaces.PortVariable;
import java.awt.image.BufferedImage;
import java.io.Serializable;

/**
 * A port for buffered images (used for camera sensor)
 * @author Peter Wild, Krystian Szczurek, Georg Klima
 */
@SuppressWarnings("serial")
public class BufferedImage_port implements PortVariable, Serializable {
	
	/**
	 * private buffered image (reference!)
	 */
	private BufferedImage _value;
	
	/**
	 * Copies its internal state from a source port variable.
	 * WARNING: here a deep copy would be more secure, but a shallow copy is
	 * sufficient, because our ImageAcquisition alwas delivers new instances
	 */
	public void copyValueFrom(PortVariable source) {
		_value = ((BufferedImage_port)source).getImage();
    }
	
    /**
     * Returns its internal state
     * @return buffered image (from camera)
     */
    public BufferedImage getImage() {
        return _value;
    }
    
    /**
     * Sets internal state
     * @param value buffered image from camera
     */
    public void setImage(BufferedImage value) {
    	_value = value;
    }
    
    /**
     * Prints its state (BufferedImage)
     */
    public String toString() {
        return "BufferedImage";
    }
}
