/* JOSX
Copyright (C) 2005 Brian Bagnall, Lawrie Griffiths

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

Contact:
Brian Bagnall, Lawrie Griffiths
http://lejos.sourceforge.net/
*/
package josx.rcxcomm;

import java.io.*;

/** RCXLNPPort provides an interface similar to java.net.Socket
 * Adapted from original code created by the LEGO3 Team at DTU-IAU
 * This version of RCXPort uses the Legos Network protocol (LNP).
 * This allow communication with LegOS programs or PC LegOS applications.
 * This version of RCXPort uses the Integrity Layer of LNP. This ensures 
 * packets are not corrupted, but does not ensure that they get through. 
 * Packets can get lost. This version does not support addressing.  
 * A two layer protocol stak is used consisting of LNPIntegrityHandler
 * and LNPHandler.
 * @author Brian Bagnall
 * @author Lawrie Griffiths
 */
public class RCXLNPPort extends RCXAbstractPort {
  public RCXLNPPort() throws IOException {
    super((PacketHandler) new LNPIntegrityHandler(
                       (PacketHandler) new LNPHandler(), (byte) 0xf0));
    if (packetHandler.getError() != 0) throw new IOException("Tower open failed");
  }

  public RCXLNPPort(String port) throws IOException {
    super(port,(PacketHandler) new LNPIntegrityHandler(
                       (PacketHandler) new LNPHandler(), (byte) 0xf0));
    if (packetHandler.getError() != 0) throw new IOException("Tower open failed");
  }
}
